@@ -188,7 +188,7 @@ class System:
         if not self.f:
             from . import kalmd
 
-            self.kalman_gain, self.P_steady = kalmd(self.sysd, Q=self.Q, R=self.R)
+            self.kalman_gain = kalmd(self.sysd, Q=self.Q, R=self.R)
         else:
             m = self.sysd.A.shape[0]
             M = np.concatenate(
@@ -405,40 +405,3 @@ class System:
         Process noise or measurement noise covariance matrix
         """
         return np.diag(np.square(elems))
-
-    def export_cpp_coeffs(
-        self,
-        class_name,
-        header_path_prefix="",
-        header_extension="hpp",
-        period_variant=False,
-    ):
-        """Exports matrices to pair of C++ source files.
-
-        Keyword arguments:
-        class_name -- subsystem class name in camel case
-        header_path_prefix -- path prefix in which header exists
-        header_extension -- file extension of header file (default: "hpp")
-        period_variant -- True to use PeriodVariantLoop, False to use
-                          StateSpaceLoop
-        """
-        from . import system_writer
-
-        system_writer = system_writer.SystemWriter(
-            self, class_name, header_path_prefix, header_extension, period_variant
-        )
-        system_writer.write_cpp_header()
-        system_writer.write_cpp_source()
-
-    def export_java_coeffs(self, class_name, period_variant=False):
-        """Exports matrices to a Java source file.
-
-        Keyword arguments:
-        class_name -- subsystem class name in camel case
-        period_variant -- True to use PeriodVariantLoop, False to use
-                          StateSpaceLoop
-        """
-        system_writer = fct.system_writer.SystemWriter(
-            self, class_name, "", "", period_variant
-        )
-        system_writer.write_java_source()
